Class: Google::Cloud::Batch::V1::AllocationPolicy::AttachedDisk

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/batch/v1/job.rb

Overview

A new or an existing persistent disk attached to a VM instance.

Instance Attribute Summary collapse

Instance Attribute Details

#device_name ⇒ ::String

Returns Device name that the guest operating system will see. If not specified, this is default to the disk name.

Returns:

  • (::String) —

    Device name that the guest operating system will see. If not specified, this is default to the disk name.



318
319
320
321
# File 'proto_docs/google/cloud/batch/v1/job.rb', line 318

class AttachedDisk
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#existing_disk ⇒ ::String

Returns Name of an existing PD.

Returns:

  • (::String) —

    Name of an existing PD.



318
319
320
321
# File 'proto_docs/google/cloud/batch/v1/job.rb', line 318

class AttachedDisk
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#new_disk ⇒ ::Google::Cloud::Batch::V1::AllocationPolicy::Disk



318
319
320
321
# File 'proto_docs/google/cloud/batch/v1/job.rb', line 318

class AttachedDisk
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end