Class: Google::Cloud::Batch::V1::AllocationPolicy::InstancePolicyOrTemplate

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/batch/v1/job.rb

Overview

Either an InstancePolicy or an instance template.

Instance Attribute Summary collapse

Instance Attribute Details

#instance_template ⇒ ::String

Returns Name of an instance template used to create VMs. Named the field as 'instance_template' instead of 'template' to avoid c++ keyword conflict.

Returns:

  • (::String) —

    Name of an instance template used to create VMs. Named the field as 'instance_template' instead of 'template' to avoid c++ keyword conflict.



372
373
374
375
# File 'proto_docs/google/cloud/batch/v1/job.rb', line 372

class InstancePolicyOrTemplate
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#policy ⇒ ::Google::Cloud::Batch::V1::AllocationPolicy::InstancePolicy

Returns InstancePolicy.



372
373
374
375
# File 'proto_docs/google/cloud/batch/v1/job.rb', line 372

class InstancePolicyOrTemplate
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end