Class: Google::Cloud::Batch::V1::AllocationPolicy::LocationPolicy
- Inherits:
-
Object
- Object
- Google::Cloud::Batch::V1::AllocationPolicy::LocationPolicy
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/batch/v1/job.rb
Instance Attribute Summary collapse
-
#allowed_locations ⇒ ::Array<::String>
A list of location names that are allowed for the job's VMs formatted as URLs.
Instance Attribute Details
#allowed_locations ⇒ ::Array<::String>
Returns A list of location names that are allowed for the job's VMs formatted
as URLs. Each location can be a region or a zone, but you can only
specify one region or multiple zones in one region per job. For example,
["regions/us-central1"] allow VMs in any zones in region
us-central1, and ["zones/us-central1-a", "zones/us-central1-c"]
only allow VMs in zones us-central1-a and us-central1-c. However,
["regions/us-central1", "zones/us-central1-a", "zones/us-central1-b", "zones/us-west1-a"] causes an error because it contains multiple regions
(us-central1 and us-west1).
The specified region or zones must be in the same region in which the job is created starting on the following dates:
-
For projects that have successfully submitted before July 31, 2026 at least one job that uses the
allowedLocations[]field with any region or zones outside of the job's location, the changes are starting on June 30, 2027. -
For all other projects, the changes are starting on July 31, 2026.
For example, for job projects/123/locations/us-central1/jobs/jobid,
the specified region or zones must be in us-central1. Using a
different region (e.g. regions/us-west1) or a zone not in
us-central1 (e.g. zones/us-west1-a) causes an error.
390 391 392 393 |
# File 'proto_docs/google/cloud/batch/v1/job.rb', line 390 class LocationPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |