Class: Google::Cloud::Batch::V1::Environment

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/batch/v1/task.rb

Overview

An Environment describes a collection of environment variables to set when executing Tasks.

Defined Under Namespace

Classes: VariablesEntry

Instance Attribute Summary collapse

Instance Attribute Details

#variables ⇒ ::Google::Protobuf::Map{::String => ::String}

Returns A map of environment variable names to values.

Returns:

  • (::Google::Protobuf::Map{::String => ::String}) —

    A map of environment variable names to values.



313
314
315
316
317
318
319
320
321
322
323
324
325
# File 'proto_docs/google/cloud/batch/v1/task.rb', line 313

class Environment
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class VariablesEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end