Class: Google::Cloud::Batch::V1::Runnable::Container
- Inherits:
-
Object
- Object
- Google::Cloud::Batch::V1::Runnable::Container
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/batch/v1/task.rb
Overview
Container runnable.
Instance Attribute Summary collapse
-
#block_external_network ⇒ ::Boolean
If set to true, external network access to and from container will be blocked.
-
#commands ⇒ ::Array<::String>
Overrides the
CMDspecified in the container. -
#entrypoint ⇒ ::String
Overrides the
ENTRYPOINTspecified in the container. -
#image_uri ⇒ ::String
The URI to pull the container image from.
-
#options ⇒ ::String
Arbitrary additional options to include in the "docker run" command when running this container, e.g.
-
#password ⇒ ::String
Optional password for logging in to a docker registry.
-
#username ⇒ ::String
Optional username for logging in to a docker registry.
-
#volumes ⇒ ::Array<::String>
Volumes to mount (bind mount) from the host machine files or directories into the container, formatted to match docker run's --volume option, e.g.
Instance Attribute Details
#block_external_network ⇒ ::Boolean
Returns If set to true, external network access to and from container will be blocked. The container will use the default internal network 'goog-internal'.
171 172 173 174 |
# File 'proto_docs/google/cloud/batch/v1/task.rb', line 171 class Container include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#commands ⇒ ::Array<::String>
Returns Overrides the CMD specified in the container. If there is an ENTRYPOINT
(either in the container image or with the entrypoint field below) then
commands are appended as arguments to the ENTRYPOINT.
171 172 173 174 |
# File 'proto_docs/google/cloud/batch/v1/task.rb', line 171 class Container include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#entrypoint ⇒ ::String
Returns Overrides the ENTRYPOINT specified in the container.
171 172 173 174 |
# File 'proto_docs/google/cloud/batch/v1/task.rb', line 171 class Container include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#image_uri ⇒ ::String
Returns The URI to pull the container image from.
171 172 173 174 |
# File 'proto_docs/google/cloud/batch/v1/task.rb', line 171 class Container include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#options ⇒ ::String
Returns Arbitrary additional options to include in the "docker run" command when running this container, e.g. "--network host".
171 172 173 174 |
# File 'proto_docs/google/cloud/batch/v1/task.rb', line 171 class Container include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#password ⇒ ::String
Returns Optional password for logging in to a docker registry. If password matches "projects//secrets//versions/*" then Batch will read the password from the Secret Manager;.
171 172 173 174 |
# File 'proto_docs/google/cloud/batch/v1/task.rb', line 171 class Container include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#username ⇒ ::String
Returns Optional username for logging in to a docker registry. If username matches "projects//secrets//versions/*" then Batch will read the username from the Secret Manager.
171 172 173 174 |
# File 'proto_docs/google/cloud/batch/v1/task.rb', line 171 class Container include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#volumes ⇒ ::Array<::String>
Returns Volumes to mount (bind mount) from the host machine files or directories into the container, formatted to match docker run's --volume option, e.g. /foo:/bar, or /foo:/bar:ro.
171 172 173 174 |
# File 'proto_docs/google/cloud/batch/v1/task.rb', line 171 class Container include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |