Class: Google::Cloud::Batch::V1::Volume

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/batch/v1/volume.rb

Overview

Volume and mount parameters to be associated with a TaskSpec. A TaskSpec might describe zero, one, or multiple volumes to be mounted as part of the task.

Instance Attribute Summary collapse

Instance Attribute Details

#device_name ⇒ ::String

Returns Device name of an attached disk.

Returns:

  • (::String) —

    Device name of an attached disk



49
50
51
52
# File 'proto_docs/google/cloud/batch/v1/volume.rb', line 49

class Volume
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#gcs ⇒ ::Google::Cloud::Batch::V1::GCS

Returns A Google Cloud Storage source for the volume.

Returns:



49
50
51
52
# File 'proto_docs/google/cloud/batch/v1/volume.rb', line 49

class Volume
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#mount_options ⇒ ::Array<::String>

Returns Mount options For Google Cloud Storage, mount options are the global options supported by gcsfuse tool. Batch will use them to mount the volume with the following command: "gcsfuse [global options] bucket mountpoint". For PD, NFS, mount options are these supported by /etc/fstab. Batch will use Fstab to mount such volumes. https://help.ubuntu.com/community/Fstab.

Returns:

  • (::Array<::String>) —

    Mount options For Google Cloud Storage, mount options are the global options supported by gcsfuse tool. Batch will use them to mount the volume with the following command: "gcsfuse [global options] bucket mountpoint". For PD, NFS, mount options are these supported by /etc/fstab. Batch will use Fstab to mount such volumes. https://help.ubuntu.com/community/Fstab



49
50
51
52
# File 'proto_docs/google/cloud/batch/v1/volume.rb', line 49

class Volume
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#mount_path ⇒ ::String

Returns Mount path for the volume, e.g. /mnt/share.

Returns:

  • (::String) —

    Mount path for the volume, e.g. /mnt/share



49
50
51
52
# File 'proto_docs/google/cloud/batch/v1/volume.rb', line 49

class Volume
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#nfs ⇒ ::Google::Cloud::Batch::V1::NFS

Returns An NFS source for the volume (could be a Filestore, for example).

Returns:



49
50
51
52
# File 'proto_docs/google/cloud/batch/v1/volume.rb', line 49

class Volume
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end