Class: Google::Cloud::Batch::V1::AllocationPolicy
- Inherits:
-
Object
- Object
- Google::Cloud::Batch::V1::AllocationPolicy
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/batch/v1/job.rb
Overview
A Job's resource allocation policy describes when, where, and how compute resources should be allocated for the Job.
Defined Under Namespace
Modules: ProvisioningModel Classes: Accelerator, AttachedDisk, Disk, InstancePolicy, InstancePolicyOrTemplate, LabelsEntry, LocationPolicy, NetworkInterface, NetworkPolicy
Instance Attribute Summary collapse
-
#instances ⇒ ::Array<::Google::Cloud::Batch::V1::AllocationPolicy::InstancePolicyOrTemplate>
Describe instances that can be created by this AllocationPolicy.
-
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Labels applied to all VM instances and other resources created by AllocationPolicy.
-
#location ⇒ ::Google::Cloud::Batch::V1::AllocationPolicy::LocationPolicy
Location where compute resources should be allocated for the Job.
-
#network ⇒ ::Google::Cloud::Batch::V1::AllocationPolicy::NetworkPolicy
The network policy.
Instance Attribute Details
#instances ⇒ ::Array<::Google::Cloud::Batch::V1::AllocationPolicy::InstancePolicyOrTemplate>
Returns Describe instances that can be created by this AllocationPolicy. Only instances is supported now.
271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 |
# File 'proto_docs/google/cloud/batch/v1/job.rb', line 271 class AllocationPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] allowed_locations # @return [::Array<::String>] # A list of allowed location names represented by internal URLs, # First location in the list must be a region. # for example, # ["regions/us-central1"] allow VMs in region us-central1, # ["regions/us-central1", "zones/us-central1-a"] only allow VMs in zone # us-central1-a. class LocationPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # A new persistent disk. # @!attribute [rw] image # @return [::String] # Name of a public or custom image used as the data source. # @!attribute [rw] snapshot # @return [::String] # Name of a snapshot used as the data source. # @!attribute [rw] type # @return [::String] # Disk type as shown in `gcloud compute disk-types list` # For example, "pd-ssd", "pd-standard", "pd-balanced". # @!attribute [rw] size_gb # @return [::Integer] # Disk size in GB. # This field is ignored if `data_source` is `disk` or `image`. class Disk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # A new or an existing persistent disk attached to a VM instance. # @!attribute [rw] new_disk # @return [::Google::Cloud::Batch::V1::AllocationPolicy::Disk] # @!attribute [rw] existing_disk # @return [::String] # Name of an existing PD. # @!attribute [rw] device_name # @return [::String] # Device name that the guest operating system will see. # If not specified, this is default to the disk name. class AttachedDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Accelerator describes Compute Engine accelerators to be attached to VMs. # @!attribute [rw] type # @return [::String] # The accelerator type. For example, "nvidia-tesla-t4". # See `gcloud compute accelerator-types list`. # @!attribute [rw] count # @return [::Integer] # The number of accelerators of this type. class Accelerator include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # InstancePolicy describes an instance type and resources attached to each VM # created by this InstancePolicy. # @!attribute [rw] machine_type # @return [::String] # The Compute Engine machine type. # @!attribute [rw] min_cpu_platform # @return [::String] # The minimum CPU platform. # See # `https://cloud.google.com/compute/docs/instances/specify-min-cpu-platform`. # Not yet implemented. # @!attribute [rw] provisioning_model # @return [::Google::Cloud::Batch::V1::AllocationPolicy::ProvisioningModel] # The provisioning model. # @!attribute [rw] accelerators # @return [::Array<::Google::Cloud::Batch::V1::AllocationPolicy::Accelerator>] # The accelerators attached to each VM instance. # Not yet implemented. # @!attribute [rw] disks # @return [::Array<::Google::Cloud::Batch::V1::AllocationPolicy::AttachedDisk>] # Non-boot disks to be attached for each VM created by this InstancePolicy. # New disks will be deleted when the attached VM is deleted. class InstancePolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Either an InstancePolicy or an instance template. # @!attribute [rw] policy # @return [::Google::Cloud::Batch::V1::AllocationPolicy::InstancePolicy] # InstancePolicy. # @!attribute [rw] instance_template # @return [::String] # Name of an instance template used to create VMs. # Named the field as 'instance_template' instead of 'template' to avoid # c++ keyword conflict. class InstancePolicyOrTemplate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # A network interface. # @!attribute [rw] network # @return [::String] # The URL of the network resource. # @!attribute [rw] subnetwork # @return [::String] # The URL of the Subnetwork resource. # @!attribute [rw] no_external_ip_address # @return [::Boolean] # Default is false (with an external IP address). Required if # no external public IP address is attached to the VM. If no external # public IP address, additional configuration is required to allow the VM # to access Google Services. See # https://cloud.google.com/vpc/docs/configure-private-google-access and # https://cloud.google.com/nat/docs/gce-example#create-nat for more # information. class NetworkInterface include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # NetworkPolicy describes VM instance network configurations. # @!attribute [rw] network_interfaces # @return [::Array<::Google::Cloud::Batch::V1::AllocationPolicy::NetworkInterface>] # Network configurations. class NetworkPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Compute Engine VM instance provisioning model. module ProvisioningModel # Unspecified. PROVISIONING_MODEL_UNSPECIFIED = 0 # Standard VM. STANDARD = 1 # SPOT VM. SPOT = 2 # Preemptible VM (PVM). # # Above SPOT VM is the preferable model for preemptible VM instances: the # old preemptible VM model (indicated by this field) is the older model, # and has been migrated to use the SPOT model as the underlying technology. # This old model will still be supported. PREEMPTIBLE = 3 end end |
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns Labels applied to all VM instances and other resources created by AllocationPolicy. Labels could be user provided or system generated. You can assign up to 64 labels. Google Compute Engine label restrictions apply. Label names that start with "goog-" or "google-" are reserved.
271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 |
# File 'proto_docs/google/cloud/batch/v1/job.rb', line 271 class AllocationPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] allowed_locations # @return [::Array<::String>] # A list of allowed location names represented by internal URLs, # First location in the list must be a region. # for example, # ["regions/us-central1"] allow VMs in region us-central1, # ["regions/us-central1", "zones/us-central1-a"] only allow VMs in zone # us-central1-a. class LocationPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # A new persistent disk. # @!attribute [rw] image # @return [::String] # Name of a public or custom image used as the data source. # @!attribute [rw] snapshot # @return [::String] # Name of a snapshot used as the data source. # @!attribute [rw] type # @return [::String] # Disk type as shown in `gcloud compute disk-types list` # For example, "pd-ssd", "pd-standard", "pd-balanced". # @!attribute [rw] size_gb # @return [::Integer] # Disk size in GB. # This field is ignored if `data_source` is `disk` or `image`. class Disk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # A new or an existing persistent disk attached to a VM instance. # @!attribute [rw] new_disk # @return [::Google::Cloud::Batch::V1::AllocationPolicy::Disk] # @!attribute [rw] existing_disk # @return [::String] # Name of an existing PD. # @!attribute [rw] device_name # @return [::String] # Device name that the guest operating system will see. # If not specified, this is default to the disk name. class AttachedDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Accelerator describes Compute Engine accelerators to be attached to VMs. # @!attribute [rw] type # @return [::String] # The accelerator type. For example, "nvidia-tesla-t4". # See `gcloud compute accelerator-types list`. # @!attribute [rw] count # @return [::Integer] # The number of accelerators of this type. class Accelerator include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # InstancePolicy describes an instance type and resources attached to each VM # created by this InstancePolicy. # @!attribute [rw] machine_type # @return [::String] # The Compute Engine machine type. # @!attribute [rw] min_cpu_platform # @return [::String] # The minimum CPU platform. # See # `https://cloud.google.com/compute/docs/instances/specify-min-cpu-platform`. # Not yet implemented. # @!attribute [rw] provisioning_model # @return [::Google::Cloud::Batch::V1::AllocationPolicy::ProvisioningModel] # The provisioning model. # @!attribute [rw] accelerators # @return [::Array<::Google::Cloud::Batch::V1::AllocationPolicy::Accelerator>] # The accelerators attached to each VM instance. # Not yet implemented. # @!attribute [rw] disks # @return [::Array<::Google::Cloud::Batch::V1::AllocationPolicy::AttachedDisk>] # Non-boot disks to be attached for each VM created by this InstancePolicy. # New disks will be deleted when the attached VM is deleted. class InstancePolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Either an InstancePolicy or an instance template. # @!attribute [rw] policy # @return [::Google::Cloud::Batch::V1::AllocationPolicy::InstancePolicy] # InstancePolicy. # @!attribute [rw] instance_template # @return [::String] # Name of an instance template used to create VMs. # Named the field as 'instance_template' instead of 'template' to avoid # c++ keyword conflict. class InstancePolicyOrTemplate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # A network interface. # @!attribute [rw] network # @return [::String] # The URL of the network resource. # @!attribute [rw] subnetwork # @return [::String] # The URL of the Subnetwork resource. # @!attribute [rw] no_external_ip_address # @return [::Boolean] # Default is false (with an external IP address). Required if # no external public IP address is attached to the VM. If no external # public IP address, additional configuration is required to allow the VM # to access Google Services. See # https://cloud.google.com/vpc/docs/configure-private-google-access and # https://cloud.google.com/nat/docs/gce-example#create-nat for more # information. class NetworkInterface include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # NetworkPolicy describes VM instance network configurations. # @!attribute [rw] network_interfaces # @return [::Array<::Google::Cloud::Batch::V1::AllocationPolicy::NetworkInterface>] # Network configurations. class NetworkPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Compute Engine VM instance provisioning model. module ProvisioningModel # Unspecified. PROVISIONING_MODEL_UNSPECIFIED = 0 # Standard VM. STANDARD = 1 # SPOT VM. SPOT = 2 # Preemptible VM (PVM). # # Above SPOT VM is the preferable model for preemptible VM instances: the # old preemptible VM model (indicated by this field) is the older model, # and has been migrated to use the SPOT model as the underlying technology. # This old model will still be supported. PREEMPTIBLE = 3 end end |
#location ⇒ ::Google::Cloud::Batch::V1::AllocationPolicy::LocationPolicy
Returns Location where compute resources should be allocated for the Job.
271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 |
# File 'proto_docs/google/cloud/batch/v1/job.rb', line 271 class AllocationPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] allowed_locations # @return [::Array<::String>] # A list of allowed location names represented by internal URLs, # First location in the list must be a region. # for example, # ["regions/us-central1"] allow VMs in region us-central1, # ["regions/us-central1", "zones/us-central1-a"] only allow VMs in zone # us-central1-a. class LocationPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # A new persistent disk. # @!attribute [rw] image # @return [::String] # Name of a public or custom image used as the data source. # @!attribute [rw] snapshot # @return [::String] # Name of a snapshot used as the data source. # @!attribute [rw] type # @return [::String] # Disk type as shown in `gcloud compute disk-types list` # For example, "pd-ssd", "pd-standard", "pd-balanced". # @!attribute [rw] size_gb # @return [::Integer] # Disk size in GB. # This field is ignored if `data_source` is `disk` or `image`. class Disk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # A new or an existing persistent disk attached to a VM instance. # @!attribute [rw] new_disk # @return [::Google::Cloud::Batch::V1::AllocationPolicy::Disk] # @!attribute [rw] existing_disk # @return [::String] # Name of an existing PD. # @!attribute [rw] device_name # @return [::String] # Device name that the guest operating system will see. # If not specified, this is default to the disk name. class AttachedDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Accelerator describes Compute Engine accelerators to be attached to VMs. # @!attribute [rw] type # @return [::String] # The accelerator type. For example, "nvidia-tesla-t4". # See `gcloud compute accelerator-types list`. # @!attribute [rw] count # @return [::Integer] # The number of accelerators of this type. class Accelerator include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # InstancePolicy describes an instance type and resources attached to each VM # created by this InstancePolicy. # @!attribute [rw] machine_type # @return [::String] # The Compute Engine machine type. # @!attribute [rw] min_cpu_platform # @return [::String] # The minimum CPU platform. # See # `https://cloud.google.com/compute/docs/instances/specify-min-cpu-platform`. # Not yet implemented. # @!attribute [rw] provisioning_model # @return [::Google::Cloud::Batch::V1::AllocationPolicy::ProvisioningModel] # The provisioning model. # @!attribute [rw] accelerators # @return [::Array<::Google::Cloud::Batch::V1::AllocationPolicy::Accelerator>] # The accelerators attached to each VM instance. # Not yet implemented. # @!attribute [rw] disks # @return [::Array<::Google::Cloud::Batch::V1::AllocationPolicy::AttachedDisk>] # Non-boot disks to be attached for each VM created by this InstancePolicy. # New disks will be deleted when the attached VM is deleted. class InstancePolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Either an InstancePolicy or an instance template. # @!attribute [rw] policy # @return [::Google::Cloud::Batch::V1::AllocationPolicy::InstancePolicy] # InstancePolicy. # @!attribute [rw] instance_template # @return [::String] # Name of an instance template used to create VMs. # Named the field as 'instance_template' instead of 'template' to avoid # c++ keyword conflict. class InstancePolicyOrTemplate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # A network interface. # @!attribute [rw] network # @return [::String] # The URL of the network resource. # @!attribute [rw] subnetwork # @return [::String] # The URL of the Subnetwork resource. # @!attribute [rw] no_external_ip_address # @return [::Boolean] # Default is false (with an external IP address). Required if # no external public IP address is attached to the VM. If no external # public IP address, additional configuration is required to allow the VM # to access Google Services. See # https://cloud.google.com/vpc/docs/configure-private-google-access and # https://cloud.google.com/nat/docs/gce-example#create-nat for more # information. class NetworkInterface include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # NetworkPolicy describes VM instance network configurations. # @!attribute [rw] network_interfaces # @return [::Array<::Google::Cloud::Batch::V1::AllocationPolicy::NetworkInterface>] # Network configurations. class NetworkPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Compute Engine VM instance provisioning model. module ProvisioningModel # Unspecified. PROVISIONING_MODEL_UNSPECIFIED = 0 # Standard VM. STANDARD = 1 # SPOT VM. SPOT = 2 # Preemptible VM (PVM). # # Above SPOT VM is the preferable model for preemptible VM instances: the # old preemptible VM model (indicated by this field) is the older model, # and has been migrated to use the SPOT model as the underlying technology. # This old model will still be supported. PREEMPTIBLE = 3 end end |
#network ⇒ ::Google::Cloud::Batch::V1::AllocationPolicy::NetworkPolicy
Returns The network policy.
271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 |
# File 'proto_docs/google/cloud/batch/v1/job.rb', line 271 class AllocationPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] allowed_locations # @return [::Array<::String>] # A list of allowed location names represented by internal URLs, # First location in the list must be a region. # for example, # ["regions/us-central1"] allow VMs in region us-central1, # ["regions/us-central1", "zones/us-central1-a"] only allow VMs in zone # us-central1-a. class LocationPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # A new persistent disk. # @!attribute [rw] image # @return [::String] # Name of a public or custom image used as the data source. # @!attribute [rw] snapshot # @return [::String] # Name of a snapshot used as the data source. # @!attribute [rw] type # @return [::String] # Disk type as shown in `gcloud compute disk-types list` # For example, "pd-ssd", "pd-standard", "pd-balanced". # @!attribute [rw] size_gb # @return [::Integer] # Disk size in GB. # This field is ignored if `data_source` is `disk` or `image`. class Disk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # A new or an existing persistent disk attached to a VM instance. # @!attribute [rw] new_disk # @return [::Google::Cloud::Batch::V1::AllocationPolicy::Disk] # @!attribute [rw] existing_disk # @return [::String] # Name of an existing PD. # @!attribute [rw] device_name # @return [::String] # Device name that the guest operating system will see. # If not specified, this is default to the disk name. class AttachedDisk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Accelerator describes Compute Engine accelerators to be attached to VMs. # @!attribute [rw] type # @return [::String] # The accelerator type. For example, "nvidia-tesla-t4". # See `gcloud compute accelerator-types list`. # @!attribute [rw] count # @return [::Integer] # The number of accelerators of this type. class Accelerator include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # InstancePolicy describes an instance type and resources attached to each VM # created by this InstancePolicy. # @!attribute [rw] machine_type # @return [::String] # The Compute Engine machine type. # @!attribute [rw] min_cpu_platform # @return [::String] # The minimum CPU platform. # See # `https://cloud.google.com/compute/docs/instances/specify-min-cpu-platform`. # Not yet implemented. # @!attribute [rw] provisioning_model # @return [::Google::Cloud::Batch::V1::AllocationPolicy::ProvisioningModel] # The provisioning model. # @!attribute [rw] accelerators # @return [::Array<::Google::Cloud::Batch::V1::AllocationPolicy::Accelerator>] # The accelerators attached to each VM instance. # Not yet implemented. # @!attribute [rw] disks # @return [::Array<::Google::Cloud::Batch::V1::AllocationPolicy::AttachedDisk>] # Non-boot disks to be attached for each VM created by this InstancePolicy. # New disks will be deleted when the attached VM is deleted. class InstancePolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Either an InstancePolicy or an instance template. # @!attribute [rw] policy # @return [::Google::Cloud::Batch::V1::AllocationPolicy::InstancePolicy] # InstancePolicy. # @!attribute [rw] instance_template # @return [::String] # Name of an instance template used to create VMs. # Named the field as 'instance_template' instead of 'template' to avoid # c++ keyword conflict. class InstancePolicyOrTemplate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # A network interface. # @!attribute [rw] network # @return [::String] # The URL of the network resource. # @!attribute [rw] subnetwork # @return [::String] # The URL of the Subnetwork resource. # @!attribute [rw] no_external_ip_address # @return [::Boolean] # Default is false (with an external IP address). Required if # no external public IP address is attached to the VM. If no external # public IP address, additional configuration is required to allow the VM # to access Google Services. See # https://cloud.google.com/vpc/docs/configure-private-google-access and # https://cloud.google.com/nat/docs/gce-example#create-nat for more # information. class NetworkInterface include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # NetworkPolicy describes VM instance network configurations. # @!attribute [rw] network_interfaces # @return [::Array<::Google::Cloud::Batch::V1::AllocationPolicy::NetworkInterface>] # Network configurations. class NetworkPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Compute Engine VM instance provisioning model. module ProvisioningModel # Unspecified. PROVISIONING_MODEL_UNSPECIFIED = 0 # Standard VM. STANDARD = 1 # SPOT VM. SPOT = 2 # Preemptible VM (PVM). # # Above SPOT VM is the preferable model for preemptible VM instances: the # old preemptible VM model (indicated by this field) is the older model, # and has been migrated to use the SPOT model as the underlying technology. # This old model will still be supported. PREEMPTIBLE = 3 end end |