Class: Google::Cloud::Batch::V1::AllocationPolicy::Disk
- Inherits:
-
Object
- Object
- Google::Cloud::Batch::V1::AllocationPolicy::Disk
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/batch/v1/job.rb
Overview
A new persistent disk.
Instance Attribute Summary collapse
-
#image ⇒ ::String
Name of a public or custom image used as the data source.
-
#size_gb ⇒ ::Integer
Disk size in GB.
-
#snapshot ⇒ ::String
Name of a snapshot used as the data source.
-
#type ⇒ ::String
Disk type as shown in
gcloud compute disk-types listFor example, "pd-ssd", "pd-standard", "pd-balanced".
Instance Attribute Details
#image ⇒ ::String
Returns Name of a public or custom image used as the data source.
303 304 305 306 |
# File 'proto_docs/google/cloud/batch/v1/job.rb', line 303 class Disk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#size_gb ⇒ ::Integer
Returns Disk size in GB.
This field is ignored if data_source is disk or image.
303 304 305 306 |
# File 'proto_docs/google/cloud/batch/v1/job.rb', line 303 class Disk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#snapshot ⇒ ::String
Returns Name of a snapshot used as the data source.
303 304 305 306 |
# File 'proto_docs/google/cloud/batch/v1/job.rb', line 303 class Disk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#type ⇒ ::String
Returns Disk type as shown in gcloud compute disk-types list
For example, "pd-ssd", "pd-standard", "pd-balanced".
303 304 305 306 |
# File 'proto_docs/google/cloud/batch/v1/job.rb', line 303 class Disk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |