Class: Google::Cloud::Batch::V1::AllocationPolicy::LocationPolicy
- Inherits:
-
Object
- Object
- Google::Cloud::Batch::V1::AllocationPolicy::LocationPolicy
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/batch/v1/job.rb
Instance Attribute Summary collapse
-
#allowed_locations ⇒ ::Array<::String>
A list of allowed location names represented by internal URLs, First location in the list must be a region.
Instance Attribute Details
#allowed_locations ⇒ ::Array<::String>
Returns A list of allowed location names represented by internal URLs, First location in the list must be a region. for example, ["regions/us-central1"] allow VMs in region us-central1, ["regions/us-central1", "zones/us-central1-a"] only allow VMs in zone us-central1-a.
283 284 285 286 |
# File 'proto_docs/google/cloud/batch/v1/job.rb', line 283 class LocationPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |