Class: Google::Cloud::Batch::V1::Volume
- Inherits:
-
Object
- Object
- Google::Cloud::Batch::V1::Volume
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/batch/v1/volume.rb
Overview
Volume and mount parameters to be associated with a TaskSpec. A TaskSpec might describe zero, one, or multiple volumes to be mounted as part of the task.
Instance Attribute Summary collapse
-
#device_name ⇒ ::String
Device name of an attached disk.
-
#gcs ⇒ ::Google::Cloud::Batch::V1::GCS
A Google Cloud Storage source for the volume.
-
#mount_options ⇒ ::Array<::String>
Mount options For Google Cloud Storage, mount options are the global options supported by gcsfuse tool.
-
#mount_path ⇒ ::String
Mount path for the volume, e.g.
-
#nfs ⇒ ::Google::Cloud::Batch::V1::NFS
An NFS source for the volume (could be a Filestore, for example).
Instance Attribute Details
#device_name ⇒ ::String
Returns Device name of an attached disk.
49 50 51 52 |
# File 'proto_docs/google/cloud/batch/v1/volume.rb', line 49 class Volume include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#gcs ⇒ ::Google::Cloud::Batch::V1::GCS
Returns A Google Cloud Storage source for the volume.
49 50 51 52 |
# File 'proto_docs/google/cloud/batch/v1/volume.rb', line 49 class Volume include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#mount_options ⇒ ::Array<::String>
Returns Mount options For Google Cloud Storage, mount options are the global options supported by gcsfuse tool. Batch will use them to mount the volume with the following command: "gcsfuse [global options] bucket mountpoint". For PD, NFS, mount options are these supported by /etc/fstab. Batch will use Fstab to mount such volumes. https://help.ubuntu.com/community/Fstab.
49 50 51 52 |
# File 'proto_docs/google/cloud/batch/v1/volume.rb', line 49 class Volume include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |